@@ -23,8 +23,8 @@ class DataprocHook(YandexCloudBaseHook):
     """
     A base hook for Yandex.Cloud Data Proc.
 
-    :param connection_id: The connection ID to use when fetching connection info.
-    :type connection_id: str
+    :param yandex_conn_id: The connection ID to use when fetching connection info.
+    :type yandex_conn_id: str
     """
 
     def __init__(self, *args, **kwargs) -> None:
